config

package
v0.0.0-...-eb5d2db Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: MIT Imports: 41 Imported by: 0

Documentation

Index

Constants

const BUFFER_SIZE int = 4096

todo: use circl from cloudfare to encrypt data post quantum crystals-kyber, crystals-dilithium, sphincs=, FALCON

const IV_SIZE int = 16
const MySecret string = "abd&1*~#^2^#s0^=)^^7%c34" // must be 24 characters
const Password = "123456" // default password shipped with app

Variables

var AdsMaxMinutes int
var AlbumArray []string
var CategoriesStore = make(map[int]CategoriesStruct)
var CategoryArray []string
var DBClientcert = "" /* 1096-byte string literal not displayed */
var DBClientkey = "" /* 1732-byte string literal not displayed */
var DBaddress = "192.168.88.232:5432/radio"

var DBaddress = "localhost:5432/radio"

var DBpassword = "postgres"
var DBuser = "postgres"
var Dark = 0
var DarkButton = color.RGBA{187, 188, 201, 32}

var DarkButton = color.RGBA{162, 168, 250, 64}

var DarkDisabled = color.RGBA{187, 188, 201, 64}
var DarkFocus = color.RGBA{187, 188, 201, 64}
var DarkHover = color.RGBA{187, 188, 201, 64}
var DarkHyperlink = color.RGBA{187, 188, 201, 255}
var DarkInputBackground = color.RGBA{187, 188, 201, 32}
var DarkInputBorder = color.RGBA{187, 188, 201, 64}
var DarkPlaceholder = color.RGBA{187, 188, 201, 220}
var DarkPressed = color.RGBA{187, 188, 201, 220}
var DarkPrimary = color.RGBA{187, 188, 201, 255}
var DarkScrollBar = color.RGBA{187, 188, 201, 64}
var DarkScrollBarBackground = color.RGBA{187, 188, 201, 1}
var DarkSelection = color.RGBA{187, 188, 201, 128}
var DarkSeparator = color.RGBA{187, 188, 201, 64}
var DarkShadow = color.RGBA{187, 188, 201, 64}
var DaysStore = make(map[int]DaysStruct)
var FyneApp fyne.App
var FyneCategoryList fyne.Widget
var FyneDaysList fyne.Widget
var FyneDeviceList fyne.Widget
var FyneDeviceWin fyne.Window
var FyneFilter bool
var FyneFilterDevices bool
var FyneInventoryList fyne.Widget
var FyneInventoryWin fyne.Window
var FyneMainWin fyne.Window
var FyneMessageList fyne.Widget
var FyneMessageWin fyne.Window
var FyneScheduleList fyne.Widget
var FyneUserList fyne.Widget
var HashLocation = "/home/oem/.config/fyne/org.nh3000.nh3000/config.hash"
var HoursStore = make(map[int]HoursStruct)
var InventoryStore = make(map[int]InventoryStruct)
var InventoryStoreCurrent = []InventoryStruct{}
var InventoryStoreRoots = []InventoryStruct{}
var KeyAes = []byte{35, 46, 57, 24, 85, 35, 24, 74, 87, 35, 88, 98, 66, 32, 14, 05} // must be 16 bytes

default encryption

var KeyHmac = []byte{36, 45, 53, 21, 87, 35, 24, 74, 87, 35, 88, 98, 66, 32, 14, 05} // must be 16 bytes
var Light = 1
var LightButton = color.RGBA{129, 137, 252, 250}
var LightDisabled = color.RGBA{129, 137, 252, 64}
var LightFocus = color.RGBA{129, 137, 252, 64}
var LightHover = color.RGBA{129, 137, 252, 1}
var LightHyperlink = color.RGBA{129, 137, 252, 1}
var LightInputBackground = color.RGBA{129, 137, 252, 32}
var LightInputBorder = color.RGBA{129, 137, 252, 250}
var LightPlaceholder = color.RGBA{129, 137, 252, 220}
var LightPressed = color.RGBA{129, 137, 252, 220}
var LightPrimary = color.RGBA{129, 137, 252, 255}
var LightScrollBar = color.RGBA{129, 137, 252, 250}
var LightScrollBarBackground = color.RGBA{129, 137, 252, 1}
var LightSelection = color.RGBA{129, 137, 252, 200}
var LightSeparator = color.Black
var LightShadow = color.RGBA{129, 137, 252, 64}
var LoggedOn bool
var MessageToSend string

var fyneFilterFound = false

var MyLangs = map[string]string{}/* 492 elements not displayed */

eng esp cmn

var NATS = &Natsjs{}
var NATSREPORT = &NatsjsREPORT{}
var NATSSTREAM = "NATS"
var NatsAdmin = "natsadmin"

defaults

var NatsAlias string
var NatsBucketType string
var NatsCaroot = "" /* 1448-byte string literal not displayed */
var NatsClientcert = "" /* 1538-byte string literal not displayed */
var NatsClientkey = "" /* 1706-byte string literal not displayed */
var NatsMessages = make(map[int]MessageStore)
var NatsMessagesIndex = make(map[string]bool)
var NatsMessagesIndexDevice = make(map[string]bool)

var NatsMessagesDevice = make(map[int]MessageStore)

var NatsMsgMaxAge string
var NatsNodeUUID string
var NatsQueueDurable = "snatsdurable"
var NatsQueuePassword = "987654321098765432109876"
var NatsServer = "nats://192.168.88.232:4222"
var NatsUser = "natsoperator"
var NatsUserAuthorizations = "natsauthorizations"
var NatsUserAuthorizationsPassword = "PASSWORD"
var NatsUserCommands = "natscommands"
var NatsUserCommandsPassword = "PASSWORD"
var NatsUserDevices = "natsdevices"
var NatsUserDevicesPassword = "PASSWORD"
var NatsUserEvents = "natsevents"
var NatsUserEventsPassword = "PASSWORD"
var NatsUserPassword = "hjscr44iod"
var NewNatsDone = false
var NewPGSlDone = false
var OAJSON = OA{}
var PasswordHash string
var PreferedLanguage string
var PreferencesLocation = "/home/oem/.config/fyne/org.nh3000.nh3000/preferences.json"
var Retro = 2
var RetroButton = color.RGBA{116, 207, 103, 250}
var RetroDisabled = color.RGBA{116, 207, 103, 64}
var RetroFocus = color.RGBA{116, 207, 103, 64}
var RetroHover = color.RGBA{116, 207, 103, 1}
var RetroHyperlink = color.RGBA{116, 207, 103, 1}
var RetroInputBackground = color.RGBA{116, 207, 103, 32}
var RetroInputBorder = color.RGBA{116, 207, 103, 250}
var RetroPlaceholder = color.RGBA{116, 207, 103, 255}
var RetroPressed = color.RGBA{116, 207, 103, 220}
var RetroPrimary = color.RGBA{116, 207, 103, 255}
var RetroScrollBar = color.RGBA{116, 207, 103, 250}
var RetroScrollBarBackground = color.RGBA{116, 207, 103, 1}
var RetroSelection = color.RGBA{116, 207, 103, 200}
var RetroSeparator = color.Black
var RetroShadow = color.RGBA{116, 207, 103, 64}
var SQL = &SQLconn{}

* The following fields need to be modified for your production * Environment to provide maximum security * * These fields are meant to be distributed at compile time and * editable in the gui. *

var ScheduleCategory int
var SchedulePlan = make(map[int]ScheduleStruct)
var ScheduleStore = make(map[int]ScheduleStruct)
var Selected = 0
var SelectedCategory int
var SelectedDay int
var SelectedHour int
var SelectedInventory int
var SelectedUser int
var TimeZoneOffset = ""
var TrafficAlbum = ""
var TrafficEnd = "YYYY-MM-DD 23:59:59"
var TrafficStart = "YYYY-MM-DD 00:00:00"
var UserStore = make(map[int]UserStruct)
var WebAddress = "https://192.168.88.233:9000" // default web address

Functions

func AlbumToArray

func AlbumToArray() []string

func CategoriesAdd

func CategoriesAdd(id string, desc string)

func CategoriesDelete

func CategoriesDelete(row int)

func CategoriesGet

func CategoriesGet()

func CategoriesToArray

func CategoriesToArray() []string

func CategoriesUpdate

func CategoriesUpdate(row int, id string, desc string)

func CategoriesWhereUsed

func CategoriesWhereUsed(cat string) int

func CategoriesWriteStub

func CategoriesWriteStub(withinventory bool) string

func CheckBucket

func CheckBucket(bucket, id, station string) bool

func ComparePasswords

func ComparePasswords(hashedPwd string, plainPwd []byte) bool

validate password

func DataStore

func DataStore(file string) fyne.URI

func DaysAdd

func DaysAdd(day string, desc string, dow int)

func DaysDelete

func DaysDelete(row int)

func DaysGet

func DaysGet()

func DaysUpdate

func DaysUpdate(row int, day string, desc string, dow int)

func Decrypt

func Decrypt(text string, secret string) string

decrypt string

func DecryptFile

func DecryptFile(filePathIn, filePathOut string) error

func DeleteBucket

func DeleteBucket(bucket, id string) error

func DeleteNatsMessage

func DeleteNatsMessage(seq uint64)

func Edit

func Edit(action string, value string) bool

func Encrypt

func Encrypt(text string, secret string) string

encrypt string

func EncryptFile

func EncryptFile(filePathIn, filePathOut string) error

func EraseMessages

func EraseMessages(queue string)

func GetBucket

func GetBucket(bucket, id, station string) []byte

func GetBucketSize

func GetBucketSize(bucket, id string) uint64

func GetDateTime

func GetDateTime(offsethours string) string

func GetLangs

func GetLangs(c string) string

do translation

func HashAndSalt

func HashAndSalt(pwd []byte) string

hash and salt

func HoursAdd

func HoursAdd(id string, desc string)

func HoursDelete

func HoursDelete(row int)

func HoursGet

func HoursGet()

func HoursUpdate

func HoursUpdate(row int, id string, desc string)

func InventoryAdd

func InventoryAdd(category string, artist string, song string, album string, songlength int, rndorder string, startson string, expireson string, adstimeslots []string, adsdayslots []string, adsmaxspins int, adsmaxspinsperhour int, lastplayed string, dateadded string, spinstoday int, spinsweek int, spinstotal int, sourcelink string) int

func InventoryDelete

func InventoryDelete(row int)

func InventoryGet

func InventoryGet()

func InventoryGetCount

func InventoryGetCount(cat string) int

func InventoryGetCurrent

func InventoryGetCurrent()

func InventoryGetRoots

func InventoryGetRoots()

func InventoryGetRow

func InventoryGetRow(category, artist, song, album string) string

func InventoryGetRowByRow

func InventoryGetRowByRow(rowin string) string

func InventoryGetRowRecovery

func InventoryGetRowRecovery(artist, song, album string) string

func InventoryGetTrafficCount

func InventoryGetTrafficCount(artist, song, album string) map[string]int

func InventorySel

func InventorySel(cat, art string)

func InventoryUpdate

func InventoryUpdate(row int, category string, artist string, song string, album string, songlength int, rndorder string, startson string, expireson string, adstimeslots []string, adsdayslots []string, adsmaxspins int, adsmaxspinsperhour int, lastplayed string, dateadded string, spinstoday int, spinsweek int, spinstotal int, sourcelink string)

func InventoryUpdateRNDORDER

func InventoryUpdateRNDORDER()

func InventoryUpdateRecovery

func InventoryUpdateRecovery(row, songlength, startson, expireson string, adstimeslots string, adsdayslots string, adsmaxspins int, adsmaxspinsperhour int, lastplayed string, dateadded string, spinstoday int, spinsweek int, spinstotal int)

func LoadHashWithDefault

func LoadHashWithDefault(filename string, password string) (string, bool)

create and load hash

func NewNatsJS

func NewNatsJS() error

func NewPGSQL

func NewPGSQL() error

func PDFCategory

func PDFCategory(rn, stationid string)

func PDFCategoryByID

func PDFCategoryByID() []core.Row

func PDFDays

func PDFDays(rn, stationid string)

func PDFDaysByDay

func PDFDaysByDay() []core.Row

func PDFHours

func PDFHours(rn, stationid string)

func PDFHoursByHour

func PDFHoursByHour() []core.Row

func PDFInventory

func PDFInventory(rn, cat, stationid string)

func PDFInventoryByCategory

func PDFInventoryByCategory(cat string) []core.Row

func PDFOutput

func PDFOutput()

func PDFSchedule

func PDFSchedule(rn, stationid string)

func PDFScheduleByDay

func PDFScheduleByDay() []core.Row

func PDFTraffic

func PDFTraffic(rn, stationid string)

func PDFTrafficByAlbum

func PDFTrafficByAlbum() []core.Row

func PDFTrafficPageHeader

func PDFTrafficPageHeader(rn string) core.Row

func ParseURL

func ParseURL(urlStr string) *url.URL

func PutBucket

func PutBucket(bucket string, id string, data []byte) error

func ReceiveMESSAGE

func ReceiveMESSAGE()

func ReceiveONAIRMP3

func ReceiveONAIRMP3()

func ReceiveONAIRMP4

func ReceiveONAIRMP4()

func ReceiveONAIRWAV

func ReceiveONAIRWAV()

func SaveHash

func SaveHash(filename string, hash string) (string, bool)

save hash

func ScheduleAdd

func ScheduleAdd(days string, hours string, position string, categories string, spinstoplay int)

func ScheduleCopy

func ScheduleCopy(dayfrom, dayto, hourfrom, hourto string)

func ScheduleDelete

func ScheduleDelete(row int)

func ScheduleGet

func ScheduleGet()

func ScheduleGetCount

func ScheduleGetCount(cat string) int

func ScheduleGetPlan

func ScheduleGetPlan(day, hour, pos string)

func ScheduleSel

func ScheduleSel(day, hour string)

func ScheduleUpdate

func ScheduleUpdate(row int, days string, hours string, position string, categories string, spinstoplay int)

func Send

func Send(subject, m, alias string) bool

func SendONAIRmp3

func SendONAIRmp3(m string)

func SendONAIRmp4

func SendONAIRmp4(m string)

func SendONAIRwav

func SendONAIRwav(m string)

func SetupDetails

func SetupDetails(queue string, age string)

func SetupNATS

func SetupNATS()

func TestBucket

func TestBucket(bucket, id string) bool

func ToPDF

func ToPDF(reportname, stationid string)

func ToString

func ToString(s []string) string

func TrafficAdd

func TrafficAdd(category, artist, song, album, playedon string)

func TrafficCheckDuplicate

func TrafficCheckDuplicate(date, alb string) int

func TrafficClear

func TrafficClear() string

func TrafficGetAlbum

func TrafficGetAlbum(hours string) string

func TrafficGetCountByAlbum

func TrafficGetCountByAlbum(date, alb string) int

func TrafficGetCountByDate

func TrafficGetCountByDate(tc, td string) int

func UserAdd

func UserAdd(userrole, userpassword, userpasswordhash string, userauthcategories, userauthaction []string)

func UserDelete

func UserDelete(row int)

func UserGet

func UserGet()

func UserUpdate

func UserUpdate(row int, userrole, userpassword, userpasswordhash string, userauthcategories, userauthaction []string)

Types

type CategoriesStruct

type CategoriesStruct struct {
	Row  int    // rowid
	Id   string // hours id
	Desc string // alias
}

type DaysStruct

type DaysStruct struct {
	Row  int    // rowid
	Day  string // message id
	Desc string // alias
	Dow  int    // hostname
}

type HoursStruct

type HoursStruct struct {
	Row  int    // rowid
	Id   string // hours id
	Desc string // alias
}

type InventoryStruct

type InventoryStruct struct {
	Row                int    // rowid
	Category           string // category
	Artist             string // artist
	Song               string // song
	Album              string // Album
	Songlength         int    // song length
	Rndorder           string // assigned weekly
	Startson           string //
	AdsTimeSlots       []string
	AdsDaySlots        []string
	AdsMaxSpins        int
	AdsMaxSpinsPerHour int
	Expireson          string
	Lastplayed         string
	Dateadded          string
	Spinstoday         int    // cleared daily at day reset
	Spinsweek          int    // spins weekly at week reset
	Spinstotal         int    // total spins
	Sourcelink         string // link to relevant source
}
type ATS struct {
	Slot string // ads time slots 00-23
}

type MessageStore

type MessageStore struct {
	MSiduuid    string // message id
	MSalias     string // alias
	MShostname  string // hostname
	MSipadrs    string // ip address
	MSmacid     string // macids
	MSmessage   string // message payload
	MSnodeuuid  string // unique id
	MSdate      string // message date
	MSsubject   string // message subject
	MSos        string // device os
	MSsequence  uint64 // consumer sequence for secure delete
	MSelementid int    // order in array
}

type MyTheme

type MyTheme struct{}

func (MyTheme) Color

func (m MyTheme) Color(name fyne.ThemeColorName, variant fyne.ThemeVariant) color.Color

func (MyTheme) Font

func (m MyTheme) Font(style fyne.TextStyle) fyne.Resource

func (MyTheme) Icon

func (m MyTheme) Icon(name fyne.ThemeIconName) fyne.Resource

func (MyTheme) SetIcon

func (m MyTheme) SetIcon(name fyne.ThemeIconName, variant fyne.ThemeVariant)

func (MyTheme) Size

func (m MyTheme) Size(name fyne.ThemeSizeName) float32

type Natsjs

type Natsjs struct {
	NatsConnect *nats.Conn
	Js          jetstream.Stream

	Jetstream jetstream.JetStream

	Obsmp3   nats.ObjectStore
	Obsmp4   nats.ObjectStore
	Obswav   nats.ObjectStore
	OnAirmp3 jetstream.KeyValue
	OnAirmp4 jetstream.KeyValue
	OnAirwav jetstream.KeyValue
	Ctx      context.Context
	Ctxcan   context.CancelFunc
}

type NatsjsREPORT

type NatsjsREPORT struct {
	NatsConnectREPORT *nats.Conn
	JsREPORT          jetstream.Stream
	JetstreamREPORT   jetstream.JetStream
	CtxREPORT         context.Context
	CtxcanREPORT      context.CancelFunc
}

type OA

type OA struct {
	Artist              string
	Album               string
	Song                string
	Length              string
	SchedRow            string
	SchedDay            string
	SchedHour           string
	SchedPosition       string
	SchedCategory       string
	SchedSpinsToPlay    string
	SchedSpinsLefToPlay string
}

type SQLconn

type SQLconn struct {
	//conn   pgx.Conn
	Pool   pgxpool.Pool
	Ctx    context.Context
	Ctxcan context.CancelFunc
}

type ScheduleStruct

type ScheduleStruct struct {
	Row         int    // rowid
	Days        string // days id
	Hours       string // hour part to play
	Position    string // position on schedule
	Category    string // category to play
	Spinstoplay int    // number of items to play
}

type UserStruct

type UserStruct struct {
	Row                int      // rowid
	Userrole           string   // role of user
	Userpassword       string   // Entered password
	Userpasswordhash   string   // Entered password
	Userauthcategories []string // authorized categories
	Userauthaction     []string // actions allowed
}

rowid serial primary key, userrole varchar(32), userpassword text not null, userpasswordhash varchar(128) not null, userauthcategories text array[128] not null, userauthactions text array[128] not null

func UserGetbyID

func UserGetbyID(id string) UserStruct

Jump to